"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Container = /** @class */ (function () {
    function Container() {
        this._map = new Map();
    }
    Container.prototype.get = function (key) {
        var entry = this._map.get(key);
        if (!entry)
            throw new Error("Missing binding of `" + key.toString() + "`.");
        if (entry.kind === 'newable' && !entry.value) {
            entry.value = this.resolve(entry.newable, entry.params);
        }
        return entry.value;
    };
    Container.prototype.bind = function (serviceIdentifier, constructor, params) {
        if (params === void 0) { params = []; }
        this._map.set(serviceIdentifier, {
            kind: 'newable',
            newable: constructor,
            params: params
        });
    };
    Container.prototype.bindToConstant = function (serviceIdentifier, constant) {
        this._map.set(serviceIdentifier, {
            kind: 'constant',
            value: constant
        });
    };
    Container.prototype.resolve = function (service, params) {
        if (params === void 0) { params = []; }
        var args = [];
        for (var _i = 0, params_1 = params; _i < params_1.length; _i++) {
            var val = params_1[_i];
            args.push(this.get(val));
        }
        return new (service.bind.apply(service, [void 0].concat(args)))();
    };
    return Container;
}());
exports.Container = Container;
//# sourceMappingURL=api.js.map